@@ -21,8 +21,8 @@
 #include <dirent.h>
 #include <tqptrqueue.h>
 #include <kdebug.h>
-#include <kfileitem.h>
-#include <kio/jobclasses.h>
+#include <tdefileitem.h>
+#include <tdeio/jobclasses.h>
 
 #ifndef NOT_USED
 #    define NOT_USED(PARAM)	( (void) (PARAM) )
@@ -71,7 +71,7 @@ namespace KDirStat
     {
 	KDirReadUnknown,	// Unknown (yet)
 	KDirReadLocal,		// Use opendir() and lstat()
-	KDirReadKIO		// Use KDE 2.x's KIO network transparent methods
+	KDirReadKIO		// Use KDE 2.x's TDEIO network transparent methods
     } KDirReadMethod;
 
 
@@ -81,8 +81,8 @@ namespace KDirStat
      *
      * Information about one single directory entry. This is the type of info
      * typically obtained by stat() / lstat() or similar calls.  Most of this
-     * can also be obtained by @ref KIO::KDirListJob, but not all: The device
-     * this file resides on is something none of KIO's many classes will tell
+     * can also be obtained by @ref TDEIO::KDirListJob, but not all: The device
+     * this file resides on is something none of TDEIO's many classes will tell
      * (since of course this only makes sense for local files) - yet this had
      * been _the_ single most requested feature of KDirStat <1.0: Stay on one
      * filesystem. To facilitate this, information about the device is
@@ -118,7 +118,7 @@ namespace KDirStat
 		   KDirInfo    *	parent = 0 );
 
 	/**
-	 * Constructor from a KFileItem, i.e. from a @ref KIO::StatJob
+	 * Constructor from a KFileItem, i.e. from a @ref TDEIO::StatJob
 	 **/
 	KFileInfo( const KFileItem *	fileItem,
 		   KDirTree  *		tree,
@@ -610,7 +610,7 @@ namespace KDirStat
 		  KDirInfo	* parent	= 0 );
 
 	/**
-	 * Constructor from a KFileItem, i.e. from a @ref KIO::StatJob
+	 * Constructor from a KFileItem, i.e. from a @ref TDEIO::StatJob
 	 **/
 	KDirInfo( const KFileItem	* fileItem,
 		  KDirTree		* tree,
@@ -1029,7 +1029,7 @@ namespace KDirStat
     class KAnyDirReadJob: public TQObject, public KDirReadJob
     {
 	Q_OBJECT
-  TQ_OBJECT
+  
 
     public:
 	/**
@@ -1071,19 +1071,19 @@ namespace KDirStat
 
     protected slots:
 	/**
-	 * Receive directory entries from a KIO job.
+	 * Receive directory entries from a TDEIO job.
 	 **/
-        void entries( KIO::Job *		job,
-		      const KIO::UDSEntryList &	entryList );
+        void entries( TDEIO::Job *		job,
+		      const TDEIO::UDSEntryList &	entryList );
 
 	/**
-	 * KIO job is finished.
+	 * TDEIO job is finished.
 	 **/
-	void finished( KIO::Job * job );
+	void finished( TDEIO::Job * job );
 
     protected:
 
-	KIO::ListJob *	_job;
+	TDEIO::ListJob *	_job;
     };
 
 
@@ -1100,7 +1100,7 @@ namespace KDirStat
     class KDirTree: public TQObject
     {
 	Q_OBJECT
-  TQ_OBJECT
+  
 
     public:
 	/**
@@ -1366,7 +1366,7 @@ namespace KDirStat
         void timeSlicedRead();
 
 	/**
-	 * Read some parameters from the global @ref KConfig object.
+	 * Read some parameters from the global @ref TDEConfig object.
 	 **/
 	void readConfig();
 
